<?php
/**
 * Plugin Name: Glossary by Arteeo
 * Plugin URI: https://github.com/Arteeo/glossary-by-arteeo/
 * Description: Glossary block for the Gutenberg editor.
 * Version: 1.0.0
 * Author: Arteeo
 * Author URI: https://github.com/Arteeo
 * License: MIT
 * License URI: https://opensource.org/licenses/MIT
 * Text Domain: glossary-by-arteeo
 * Domain Path: /languages
 * Requires PHP: 7.3
 *
 * @package arteeo\glossary
 */

namespace arteeo\glossary;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once 'php/class-glossary.php';
require_once 'php/db/class-glossary-db.php';

/**
 * Trigger uninstall
 *
 * On plugin deinstallation this function is called which does then trigger a custom action so that the plugin can be
 * correctly removed.
 *
 * @since 1.0.0
 */
function uninstall() {
	do_action( 'glossary_by_arteeo_uninstall' );
}
register_uninstall_hook( __FILE__, 'arteeo\glossary\uninstall' );

/**
 * The loader for the plugin
 *
 * @since 1.0.0
 */
class Main {
	/**
	 * The glossary.
	 *
	 * @var Glossary
	 */
	private $glossary;

	/**
	 * Db instance for the glossary.
	 *
	 * @var Glossary_DB
	 */
	private $db;

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		// Db has to be initialized here since it is used within hooks.
		$this->db = new Glossary_DB();
	}

	/**
	 * Run the plugin
	 *
	 * @since 1.0.0
	 */
	public function run() {
		/**
		 * Actions and Hooks
		 */
		$this->db->register_actions();
		add_action( 'init', array( $this, 'includes' ) );
	}

	/**
	 * Include other classes
	 *
	 * Includes the other components of the plugin
	 *
	 * @since 1.0.0
	 */
	public function includes() {
		/**
		 * Load Text Domain
		 */
		load_plugin_textdomain( 'glossary-by-arteeo', false, basename( dirname( __FILE__ ) ) . '/languages/' );

		$this->glossary = new Glossary( $this->db );
	}
}

$main = new Main();
$main->run();
